@@ -4,7 +4,7 @@ use warnings;
 
 package RT::Extension::SLA;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 =head1 NAME
 
@@ -14,24 +14,41 @@ RT::Extension::SLA - Service Level Agreements for RT
 
 RT extension to implement automated due dates using service levels.
 
-=head1 INSTALL
+=head1 INSTALLATION
 
-=over 4
+=over
 
-=item perl Makefile.PL
+=item C<perl Makefile.PL>
 
-=item make
+=item C<make>
 
-=item make install
+=item C<make install>
 
-=item make initdb (for the first time only)
+May need root permissions
 
-=item Base configuration
+=item C<make initdb>
 
-In RT 3.8 and later, you must enable the plugin by adding RT::Extension::SLA
-to your @Plugins line (or create one) like:
+Only run this the first time you install this module.
 
-    Set(@Plugins,(qw(RT::Extension::SLA)));
+If you run this twice, you may end up with duplicate data
+in your database.
+
+If you are upgrading this module, check for upgrading instructions
+in case changes need to be made to your database.
+
+=item Edit your F</opt/rt4/etc/RT_SiteConfig.pm>
+
+If you are using RT 4.2 or greater, add this line:
+
+    Plugin('RT::Extension::SLA');
+
+For RT 3.8 and 4.0, add this line:
+
+    Set(@Plugins, qw(RT::Extension::SLA));
+
+or add C<RT::Extension::SLA> to your existing C<@Plugins> line.
+
+=item Restart your webserver
 
 =back
 
@@ -168,20 +185,20 @@ so several rules applies to make things sane:
 
 =over 4
 
-=item
+=item *
 
 If requestor(s) reply multiple times and are ignored then the deadline
 is calculated using the oldest requestors' correspondence.
 
-=item
+=item *
 
 If a ticket has no requestor(s) then it has no response deadline.
 
-=item
+=item *
 
 If a ticket is created by non-requestor then due date is left unset.
 
-=item
+=item *
 
 If owner of a ticket is its requestor then his actions are treated
 as non-requestors'.
@@ -262,7 +279,7 @@ and/or reply options if event happens out of business hours, read also
 </"Configuring business hours"> below.
 
 Example:
-    
+
     'level x' => {
         OutOfHours => { Resolve => { RealMinutes => +60*24 } },
         Resolve    => { RealMinutes => 60*24 },
@@ -494,7 +511,7 @@ sub GetCustomField {
         return RT::CustomField->new( $RT::SystemUser );
     }
     my $cfs = $args{'Ticket'}->QueueObj->TicketCustomFields;
-    $cfs->Limit( FIELD => 'Name', VALUE => $args{'CustomField'} );
+    $cfs->Limit( FIELD => 'Name', VALUE => $args{'CustomField'}, CASESENSITIVE => 0 );
     return $cfs->First || RT::CustomField->new( $RT::SystemUser );
 }
 
@@ -565,7 +582,7 @@ Ruslan Zakirov E<lt>ruz@bestpractical.comE<gt>
 
 =head1 COPYRIGHT
 
-This extension is Copyright (C) 2007-2009 Best Practical Solutions, LLC.
+This extension is Copyright (C) 2007-2014 Best Practical Solutions, LLC.
 
 It is freely redistributable under the terms of version 2 of the GNU GPL.
 
